# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AccountArgs', 'Account']

@pulumi.input_type
class AccountArgs:
    def __init__(__self__, *,
                 account_name: pulumi.Input[builtins.str],
                 show_name: pulumi.Input[builtins.str],
                 allow_console: Optional[pulumi.Input[builtins.int]] = None,
                 allow_exit: Optional[pulumi.Input[builtins.int]] = None,
                 delete_uk: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 org_unit_id: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 secure_contact_info: Optional[pulumi.Input['AccountSecureContactInfoArgs']] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['AccountTagArgs']]]] = None,
                 verification_relation_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Account resource.
        :param pulumi.Input[builtins.str] account_name: 账户名称。5-20个字符。
        :param pulumi.Input[builtins.str] show_name: 显示名称。
        :param pulumi.Input[builtins.int] allow_console: 允许控制台访问，1: 允许，2: 不允许。
        :param pulumi.Input[builtins.int] allow_exit: 允许退出，1: 允许，2: 不允许。
        :param pulumi.Input[builtins.str] delete_uk: 删除标记。
        :param pulumi.Input[builtins.str] description: 描述。
        :param pulumi.Input[builtins.str] org_unit_id: 组织单元ID。传入 0 加入到 root 单元。
        :param pulumi.Input[builtins.str] password: 账户密码。
        :param pulumi.Input['AccountSecureContactInfoArgs'] secure_contact_info: 安全联系信息。
        :param pulumi.Input[builtins.str] verification_relation_id: 被继承认证主体的账号ID，给非管理员认证主体创建账号时需要，账号需已加入企业组织。默认不传，则继承企业组织管理员的认证主体。
        """
        pulumi.set(__self__, "account_name", account_name)
        pulumi.set(__self__, "show_name", show_name)
        if allow_console is not None:
            pulumi.set(__self__, "allow_console", allow_console)
        if allow_exit is not None:
            pulumi.set(__self__, "allow_exit", allow_exit)
        if delete_uk is not None:
            pulumi.set(__self__, "delete_uk", delete_uk)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if org_unit_id is not None:
            pulumi.set(__self__, "org_unit_id", org_unit_id)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if secure_contact_info is not None:
            pulumi.set(__self__, "secure_contact_info", secure_contact_info)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if verification_relation_id is not None:
            pulumi.set(__self__, "verification_relation_id", verification_relation_id)

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> pulumi.Input[builtins.str]:
        """
        账户名称。5-20个字符。
        """
        return pulumi.get(self, "account_name")

    @account_name.setter
    def account_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "account_name", value)

    @property
    @pulumi.getter(name="showName")
    def show_name(self) -> pulumi.Input[builtins.str]:
        """
        显示名称。
        """
        return pulumi.get(self, "show_name")

    @show_name.setter
    def show_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "show_name", value)

    @property
    @pulumi.getter(name="allowConsole")
    def allow_console(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        允许控制台访问，1: 允许，2: 不允许。
        """
        return pulumi.get(self, "allow_console")

    @allow_console.setter
    def allow_console(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "allow_console", value)

    @property
    @pulumi.getter(name="allowExit")
    def allow_exit(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        允许退出，1: 允许，2: 不允许。
        """
        return pulumi.get(self, "allow_exit")

    @allow_exit.setter
    def allow_exit(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "allow_exit", value)

    @property
    @pulumi.getter(name="deleteUk")
    def delete_uk(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        删除标记。
        """
        return pulumi.get(self, "delete_uk")

    @delete_uk.setter
    def delete_uk(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "delete_uk", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="orgUnitId")
    def org_unit_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        组织单元ID。传入 0 加入到 root 单元。
        """
        return pulumi.get(self, "org_unit_id")

    @org_unit_id.setter
    def org_unit_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "org_unit_id", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        账户密码。
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="secureContactInfo")
    def secure_contact_info(self) -> Optional[pulumi.Input['AccountSecureContactInfoArgs']]:
        """
        安全联系信息。
        """
        return pulumi.get(self, "secure_contact_info")

    @secure_contact_info.setter
    def secure_contact_info(self, value: Optional[pulumi.Input['AccountSecureContactInfoArgs']]):
        pulumi.set(self, "secure_contact_info", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AccountTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AccountTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="verificationRelationId")
    def verification_relation_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        被继承认证主体的账号ID，给非管理员认证主体创建账号时需要，账号需已加入企业组织。默认不传，则继承企业组织管理员的认证主体。
        """
        return pulumi.get(self, "verification_relation_id")

    @verification_relation_id.setter
    def verification_relation_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "verification_relation_id", value)


@pulumi.input_type
class _AccountState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 account_name: Optional[pulumi.Input[builtins.str]] = None,
                 allow_console: Optional[pulumi.Input[builtins.int]] = None,
                 allow_exit: Optional[pulumi.Input[builtins.int]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 delete_uk: Optional[pulumi.Input[builtins.str]] = None,
                 deleted_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 iam_role: Optional[pulumi.Input[builtins.str]] = None,
                 is_owner: Optional[pulumi.Input[builtins.int]] = None,
                 join_type: Optional[pulumi.Input[builtins.int]] = None,
                 main_name: Optional[pulumi.Input[builtins.str]] = None,
                 member_account_id: Optional[pulumi.Input[builtins.str]] = None,
                 org_id: Optional[pulumi.Input[builtins.str]] = None,
                 org_type: Optional[pulumi.Input[builtins.int]] = None,
                 org_unit_id: Optional[pulumi.Input[builtins.str]] = None,
                 org_unit_name: Optional[pulumi.Input[builtins.str]] = None,
                 org_verification_id: Optional[pulumi.Input[builtins.str]] = None,
                 owner: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 secure_contact_info: Optional[pulumi.Input['AccountSecureContactInfoArgs']] = None,
                 show_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['AccountTagArgs']]]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 verification_relation_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Account resources.
        :param pulumi.Input[builtins.str] account_id: 火山账号ID。
        :param pulumi.Input[builtins.str] account_name: 账户名称。5-20个字符。
        :param pulumi.Input[builtins.int] allow_console: 允许控制台访问，1: 允许，2: 不允许。
        :param pulumi.Input[builtins.int] allow_exit: 允许退出，1: 允许，2: 不允许。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] delete_uk: 删除标记。
        :param pulumi.Input[builtins.str] deleted_time: 删除时间。
        :param pulumi.Input[builtins.str] description: 描述。
        :param pulumi.Input[builtins.str] iam_role: IAM角色名称。
        :param pulumi.Input[builtins.int] is_owner: 是否是管理员，0.非管理员，1.管理员。
        :param pulumi.Input[builtins.int] join_type: 加入类型，1: 创建，2: 邀请。
        :param pulumi.Input[builtins.str] main_name: 主体名称。
        :param pulumi.Input[builtins.str] member_account_id: 组织成员账号ID。
        :param pulumi.Input[builtins.str] org_id: 组织ID。
        :param pulumi.Input[builtins.int] org_type: 组织类型，1.企业组织。
        :param pulumi.Input[builtins.str] org_unit_id: 组织单元ID。传入 0 加入到 root 单元。
        :param pulumi.Input[builtins.str] org_unit_name: 组织单元名称。
        :param pulumi.Input[builtins.str] org_verification_id: 认证主体ID。
        :param pulumi.Input[builtins.str] owner: 管理员ID。
        :param pulumi.Input[builtins.str] password: 账户密码。
        :param pulumi.Input['AccountSecureContactInfoArgs'] secure_contact_info: 安全联系信息。
        :param pulumi.Input[builtins.str] show_name: 显示名称。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        :param pulumi.Input[builtins.str] verification_relation_id: 被继承认证主体的账号ID，给非管理员认证主体创建账号时需要，账号需已加入企业组织。默认不传，则继承企业组织管理员的认证主体。
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if account_name is not None:
            pulumi.set(__self__, "account_name", account_name)
        if allow_console is not None:
            pulumi.set(__self__, "allow_console", allow_console)
        if allow_exit is not None:
            pulumi.set(__self__, "allow_exit", allow_exit)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if delete_uk is not None:
            pulumi.set(__self__, "delete_uk", delete_uk)
        if deleted_time is not None:
            pulumi.set(__self__, "deleted_time", deleted_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if iam_role is not None:
            pulumi.set(__self__, "iam_role", iam_role)
        if is_owner is not None:
            pulumi.set(__self__, "is_owner", is_owner)
        if join_type is not None:
            pulumi.set(__self__, "join_type", join_type)
        if main_name is not None:
            pulumi.set(__self__, "main_name", main_name)
        if member_account_id is not None:
            pulumi.set(__self__, "member_account_id", member_account_id)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if org_type is not None:
            pulumi.set(__self__, "org_type", org_type)
        if org_unit_id is not None:
            pulumi.set(__self__, "org_unit_id", org_unit_id)
        if org_unit_name is not None:
            pulumi.set(__self__, "org_unit_name", org_unit_name)
        if org_verification_id is not None:
            pulumi.set(__self__, "org_verification_id", org_verification_id)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if secure_contact_info is not None:
            pulumi.set(__self__, "secure_contact_info", secure_contact_info)
        if show_name is not None:
            pulumi.set(__self__, "show_name", show_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if verification_relation_id is not None:
            pulumi.set(__self__, "verification_relation_id", verification_relation_id)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        火山账号ID。
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        账户名称。5-20个字符。
        """
        return pulumi.get(self, "account_name")

    @account_name.setter
    def account_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_name", value)

    @property
    @pulumi.getter(name="allowConsole")
    def allow_console(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        允许控制台访问，1: 允许，2: 不允许。
        """
        return pulumi.get(self, "allow_console")

    @allow_console.setter
    def allow_console(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "allow_console", value)

    @property
    @pulumi.getter(name="allowExit")
    def allow_exit(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        允许退出，1: 允许，2: 不允许。
        """
        return pulumi.get(self, "allow_exit")

    @allow_exit.setter
    def allow_exit(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "allow_exit", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="deleteUk")
    def delete_uk(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        删除标记。
        """
        return pulumi.get(self, "delete_uk")

    @delete_uk.setter
    def delete_uk(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "delete_uk", value)

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        删除时间。
        """
        return pulumi.get(self, "deleted_time")

    @deleted_time.setter
    def deleted_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deleted_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="iamRole")
    def iam_role(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IAM角色名称。
        """
        return pulumi.get(self, "iam_role")

    @iam_role.setter
    def iam_role(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "iam_role", value)

    @property
    @pulumi.getter(name="isOwner")
    def is_owner(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        是否是管理员，0.非管理员，1.管理员。
        """
        return pulumi.get(self, "is_owner")

    @is_owner.setter
    def is_owner(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "is_owner", value)

    @property
    @pulumi.getter(name="joinType")
    def join_type(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        加入类型，1: 创建，2: 邀请。
        """
        return pulumi.get(self, "join_type")

    @join_type.setter
    def join_type(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "join_type", value)

    @property
    @pulumi.getter(name="mainName")
    def main_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        主体名称。
        """
        return pulumi.get(self, "main_name")

    @main_name.setter
    def main_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "main_name", value)

    @property
    @pulumi.getter(name="memberAccountId")
    def member_account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        组织成员账号ID。
        """
        return pulumi.get(self, "member_account_id")

    @member_account_id.setter
    def member_account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "member_account_id", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        组织ID。
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter(name="orgType")
    def org_type(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        组织类型，1.企业组织。
        """
        return pulumi.get(self, "org_type")

    @org_type.setter
    def org_type(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "org_type", value)

    @property
    @pulumi.getter(name="orgUnitId")
    def org_unit_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        组织单元ID。传入 0 加入到 root 单元。
        """
        return pulumi.get(self, "org_unit_id")

    @org_unit_id.setter
    def org_unit_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "org_unit_id", value)

    @property
    @pulumi.getter(name="orgUnitName")
    def org_unit_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        组织单元名称。
        """
        return pulumi.get(self, "org_unit_name")

    @org_unit_name.setter
    def org_unit_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "org_unit_name", value)

    @property
    @pulumi.getter(name="orgVerificationId")
    def org_verification_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        认证主体ID。
        """
        return pulumi.get(self, "org_verification_id")

    @org_verification_id.setter
    def org_verification_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "org_verification_id", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        管理员ID。
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        账户密码。
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="secureContactInfo")
    def secure_contact_info(self) -> Optional[pulumi.Input['AccountSecureContactInfoArgs']]:
        """
        安全联系信息。
        """
        return pulumi.get(self, "secure_contact_info")

    @secure_contact_info.setter
    def secure_contact_info(self, value: Optional[pulumi.Input['AccountSecureContactInfoArgs']]):
        pulumi.set(self, "secure_contact_info", value)

    @property
    @pulumi.getter(name="showName")
    def show_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        显示名称。
        """
        return pulumi.get(self, "show_name")

    @show_name.setter
    def show_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "show_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AccountTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AccountTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="verificationRelationId")
    def verification_relation_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        被继承认证主体的账号ID，给非管理员认证主体创建账号时需要，账号需已加入企业组织。默认不传，则继承企业组织管理员的认证主体。
        """
        return pulumi.get(self, "verification_relation_id")

    @verification_relation_id.setter
    def verification_relation_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "verification_relation_id", value)


@pulumi.type_token("bytepluscc:organization/account:Account")
class Account(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_name: Optional[pulumi.Input[builtins.str]] = None,
                 allow_console: Optional[pulumi.Input[builtins.int]] = None,
                 allow_exit: Optional[pulumi.Input[builtins.int]] = None,
                 delete_uk: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 org_unit_id: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 secure_contact_info: Optional[pulumi.Input[Union['AccountSecureContactInfoArgs', 'AccountSecureContactInfoArgsDict']]] = None,
                 show_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AccountTagArgs', 'AccountTagArgsDict']]]]] = None,
                 verification_relation_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        查看和管理您组织内的所有账号。每个账号可以直接放在根节点中，也可以移动到您创建的任意组织节点层级结构中，每个账号只能归属于一个节点。您可以分层树状结构管理您的组织结构以及成员账号。

        ## Import

        ```sh
        $ pulumi import bytepluscc:organization/account:Account example "account_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_name: 账户名称。5-20个字符。
        :param pulumi.Input[builtins.int] allow_console: 允许控制台访问，1: 允许，2: 不允许。
        :param pulumi.Input[builtins.int] allow_exit: 允许退出，1: 允许，2: 不允许。
        :param pulumi.Input[builtins.str] delete_uk: 删除标记。
        :param pulumi.Input[builtins.str] description: 描述。
        :param pulumi.Input[builtins.str] org_unit_id: 组织单元ID。传入 0 加入到 root 单元。
        :param pulumi.Input[builtins.str] password: 账户密码。
        :param pulumi.Input[Union['AccountSecureContactInfoArgs', 'AccountSecureContactInfoArgsDict']] secure_contact_info: 安全联系信息。
        :param pulumi.Input[builtins.str] show_name: 显示名称。
        :param pulumi.Input[builtins.str] verification_relation_id: 被继承认证主体的账号ID，给非管理员认证主体创建账号时需要，账号需已加入企业组织。默认不传，则继承企业组织管理员的认证主体。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AccountArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        查看和管理您组织内的所有账号。每个账号可以直接放在根节点中，也可以移动到您创建的任意组织节点层级结构中，每个账号只能归属于一个节点。您可以分层树状结构管理您的组织结构以及成员账号。

        ## Import

        ```sh
        $ pulumi import bytepluscc:organization/account:Account example "account_id"
        ```

        :param str resource_name: The name of the resource.
        :param AccountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AccountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_name: Optional[pulumi.Input[builtins.str]] = None,
                 allow_console: Optional[pulumi.Input[builtins.int]] = None,
                 allow_exit: Optional[pulumi.Input[builtins.int]] = None,
                 delete_uk: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 org_unit_id: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 secure_contact_info: Optional[pulumi.Input[Union['AccountSecureContactInfoArgs', 'AccountSecureContactInfoArgsDict']]] = None,
                 show_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AccountTagArgs', 'AccountTagArgsDict']]]]] = None,
                 verification_relation_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AccountArgs.__new__(AccountArgs)

            if account_name is None and not opts.urn:
                raise TypeError("Missing required property 'account_name'")
            __props__.__dict__["account_name"] = account_name
            __props__.__dict__["allow_console"] = allow_console
            __props__.__dict__["allow_exit"] = allow_exit
            __props__.__dict__["delete_uk"] = delete_uk
            __props__.__dict__["description"] = description
            __props__.__dict__["org_unit_id"] = org_unit_id
            __props__.__dict__["password"] = password
            __props__.__dict__["secure_contact_info"] = secure_contact_info
            if show_name is None and not opts.urn:
                raise TypeError("Missing required property 'show_name'")
            __props__.__dict__["show_name"] = show_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["verification_relation_id"] = verification_relation_id
            __props__.__dict__["account_id"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["deleted_time"] = None
            __props__.__dict__["iam_role"] = None
            __props__.__dict__["is_owner"] = None
            __props__.__dict__["join_type"] = None
            __props__.__dict__["main_name"] = None
            __props__.__dict__["member_account_id"] = None
            __props__.__dict__["org_id"] = None
            __props__.__dict__["org_type"] = None
            __props__.__dict__["org_unit_name"] = None
            __props__.__dict__["org_verification_id"] = None
            __props__.__dict__["owner"] = None
            __props__.__dict__["updated_time"] = None
        super(Account, __self__).__init__(
            'bytepluscc:organization/account:Account',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.str]] = None,
            account_name: Optional[pulumi.Input[builtins.str]] = None,
            allow_console: Optional[pulumi.Input[builtins.int]] = None,
            allow_exit: Optional[pulumi.Input[builtins.int]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            delete_uk: Optional[pulumi.Input[builtins.str]] = None,
            deleted_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            iam_role: Optional[pulumi.Input[builtins.str]] = None,
            is_owner: Optional[pulumi.Input[builtins.int]] = None,
            join_type: Optional[pulumi.Input[builtins.int]] = None,
            main_name: Optional[pulumi.Input[builtins.str]] = None,
            member_account_id: Optional[pulumi.Input[builtins.str]] = None,
            org_id: Optional[pulumi.Input[builtins.str]] = None,
            org_type: Optional[pulumi.Input[builtins.int]] = None,
            org_unit_id: Optional[pulumi.Input[builtins.str]] = None,
            org_unit_name: Optional[pulumi.Input[builtins.str]] = None,
            org_verification_id: Optional[pulumi.Input[builtins.str]] = None,
            owner: Optional[pulumi.Input[builtins.str]] = None,
            password: Optional[pulumi.Input[builtins.str]] = None,
            secure_contact_info: Optional[pulumi.Input[Union['AccountSecureContactInfoArgs', 'AccountSecureContactInfoArgsDict']]] = None,
            show_name: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AccountTagArgs', 'AccountTagArgsDict']]]]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            verification_relation_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Account':
        """
        Get an existing Account resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: 火山账号ID。
        :param pulumi.Input[builtins.str] account_name: 账户名称。5-20个字符。
        :param pulumi.Input[builtins.int] allow_console: 允许控制台访问，1: 允许，2: 不允许。
        :param pulumi.Input[builtins.int] allow_exit: 允许退出，1: 允许，2: 不允许。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] delete_uk: 删除标记。
        :param pulumi.Input[builtins.str] deleted_time: 删除时间。
        :param pulumi.Input[builtins.str] description: 描述。
        :param pulumi.Input[builtins.str] iam_role: IAM角色名称。
        :param pulumi.Input[builtins.int] is_owner: 是否是管理员，0.非管理员，1.管理员。
        :param pulumi.Input[builtins.int] join_type: 加入类型，1: 创建，2: 邀请。
        :param pulumi.Input[builtins.str] main_name: 主体名称。
        :param pulumi.Input[builtins.str] member_account_id: 组织成员账号ID。
        :param pulumi.Input[builtins.str] org_id: 组织ID。
        :param pulumi.Input[builtins.int] org_type: 组织类型，1.企业组织。
        :param pulumi.Input[builtins.str] org_unit_id: 组织单元ID。传入 0 加入到 root 单元。
        :param pulumi.Input[builtins.str] org_unit_name: 组织单元名称。
        :param pulumi.Input[builtins.str] org_verification_id: 认证主体ID。
        :param pulumi.Input[builtins.str] owner: 管理员ID。
        :param pulumi.Input[builtins.str] password: 账户密码。
        :param pulumi.Input[Union['AccountSecureContactInfoArgs', 'AccountSecureContactInfoArgsDict']] secure_contact_info: 安全联系信息。
        :param pulumi.Input[builtins.str] show_name: 显示名称。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        :param pulumi.Input[builtins.str] verification_relation_id: 被继承认证主体的账号ID，给非管理员认证主体创建账号时需要，账号需已加入企业组织。默认不传，则继承企业组织管理员的认证主体。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AccountState.__new__(_AccountState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["account_name"] = account_name
        __props__.__dict__["allow_console"] = allow_console
        __props__.__dict__["allow_exit"] = allow_exit
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["delete_uk"] = delete_uk
        __props__.__dict__["deleted_time"] = deleted_time
        __props__.__dict__["description"] = description
        __props__.__dict__["iam_role"] = iam_role
        __props__.__dict__["is_owner"] = is_owner
        __props__.__dict__["join_type"] = join_type
        __props__.__dict__["main_name"] = main_name
        __props__.__dict__["member_account_id"] = member_account_id
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["org_type"] = org_type
        __props__.__dict__["org_unit_id"] = org_unit_id
        __props__.__dict__["org_unit_name"] = org_unit_name
        __props__.__dict__["org_verification_id"] = org_verification_id
        __props__.__dict__["owner"] = owner
        __props__.__dict__["password"] = password
        __props__.__dict__["secure_contact_info"] = secure_contact_info
        __props__.__dict__["show_name"] = show_name
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["verification_relation_id"] = verification_relation_id
        return Account(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.str]:
        """
        火山账号ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> pulumi.Output[builtins.str]:
        """
        账户名称。5-20个字符。
        """
        return pulumi.get(self, "account_name")

    @property
    @pulumi.getter(name="allowConsole")
    def allow_console(self) -> pulumi.Output[builtins.int]:
        """
        允许控制台访问，1: 允许，2: 不允许。
        """
        return pulumi.get(self, "allow_console")

    @property
    @pulumi.getter(name="allowExit")
    def allow_exit(self) -> pulumi.Output[builtins.int]:
        """
        允许退出，1: 允许，2: 不允许。
        """
        return pulumi.get(self, "allow_exit")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="deleteUk")
    def delete_uk(self) -> pulumi.Output[builtins.str]:
        """
        删除标记。
        """
        return pulumi.get(self, "delete_uk")

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> pulumi.Output[builtins.str]:
        """
        删除时间。
        """
        return pulumi.get(self, "deleted_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="iamRole")
    def iam_role(self) -> pulumi.Output[builtins.str]:
        """
        IAM角色名称。
        """
        return pulumi.get(self, "iam_role")

    @property
    @pulumi.getter(name="isOwner")
    def is_owner(self) -> pulumi.Output[builtins.int]:
        """
        是否是管理员，0.非管理员，1.管理员。
        """
        return pulumi.get(self, "is_owner")

    @property
    @pulumi.getter(name="joinType")
    def join_type(self) -> pulumi.Output[builtins.int]:
        """
        加入类型，1: 创建，2: 邀请。
        """
        return pulumi.get(self, "join_type")

    @property
    @pulumi.getter(name="mainName")
    def main_name(self) -> pulumi.Output[builtins.str]:
        """
        主体名称。
        """
        return pulumi.get(self, "main_name")

    @property
    @pulumi.getter(name="memberAccountId")
    def member_account_id(self) -> pulumi.Output[builtins.str]:
        """
        组织成员账号ID。
        """
        return pulumi.get(self, "member_account_id")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[builtins.str]:
        """
        组织ID。
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="orgType")
    def org_type(self) -> pulumi.Output[builtins.int]:
        """
        组织类型，1.企业组织。
        """
        return pulumi.get(self, "org_type")

    @property
    @pulumi.getter(name="orgUnitId")
    def org_unit_id(self) -> pulumi.Output[builtins.str]:
        """
        组织单元ID。传入 0 加入到 root 单元。
        """
        return pulumi.get(self, "org_unit_id")

    @property
    @pulumi.getter(name="orgUnitName")
    def org_unit_name(self) -> pulumi.Output[builtins.str]:
        """
        组织单元名称。
        """
        return pulumi.get(self, "org_unit_name")

    @property
    @pulumi.getter(name="orgVerificationId")
    def org_verification_id(self) -> pulumi.Output[builtins.str]:
        """
        认证主体ID。
        """
        return pulumi.get(self, "org_verification_id")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[builtins.str]:
        """
        管理员ID。
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[builtins.str]:
        """
        账户密码。
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="secureContactInfo")
    def secure_contact_info(self) -> pulumi.Output['outputs.AccountSecureContactInfo']:
        """
        安全联系信息。
        """
        return pulumi.get(self, "secure_contact_info")

    @property
    @pulumi.getter(name="showName")
    def show_name(self) -> pulumi.Output[builtins.str]:
        """
        显示名称。
        """
        return pulumi.get(self, "show_name")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.AccountTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="verificationRelationId")
    def verification_relation_id(self) -> pulumi.Output[builtins.str]:
        """
        被继承认证主体的账号ID，给非管理员认证主体创建账号时需要，账号需已加入企业组织。默认不传，则继承企业组织管理员的认证主体。
        """
        return pulumi.get(self, "verification_relation_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'InstanceCachePerformance',
    'InstanceCapacity',
    'InstanceTag',
    'MountPointClient',
    'MountPointPermissionGroup',
    'MountPointPermissionGroupMountPoint',
    'GetInstanceCachePerformanceResult',
    'GetInstanceCapacityResult',
    'GetInstanceTagResult',
    'GetMountPointClientResult',
    'GetMountPointPermissionGroupResult',
    'GetMountPointPermissionGroupMountPointResult',
]

@pulumi.output_type
class InstanceCachePerformance(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "cacheBandwidth":
            suggest = "cache_bandwidth"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstanceCachePerformance. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstanceCachePerformance.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstanceCachePerformance.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 cache_bandwidth: Optional[builtins.int] = None):
        """
        :param builtins.int cache_bandwidth: 预配置带宽，用于增加文件系统带宽。
        """
        if cache_bandwidth is not None:
            pulumi.set(__self__, "cache_bandwidth", cache_bandwidth)

    @property
    @pulumi.getter(name="cacheBandwidth")
    def cache_bandwidth(self) -> Optional[builtins.int]:
        """
        预配置带宽，用于增加文件系统带宽。
        """
        return pulumi.get(self, "cache_bandwidth")


@pulumi.output_type
class InstanceCapacity(dict):
    def __init__(__self__, *,
                 total: Optional[builtins.float] = None,
                 used: Optional[builtins.float] = None):
        """
        :param builtins.float total: 文件系统可用总容量，单位为 GiB。
        :param builtins.float used: 文件系统已使用容量，单位为 MiB。
        """
        if total is not None:
            pulumi.set(__self__, "total", total)
        if used is not None:
            pulumi.set(__self__, "used", used)

    @property
    @pulumi.getter
    def total(self) -> Optional[builtins.float]:
        """
        文件系统可用总容量，单位为 GiB。
        """
        return pulumi.get(self, "total")

    @property
    @pulumi.getter
    def used(self) -> Optional[builtins.float]:
        """
        文件系统已使用容量，单位为 MiB。
        """
        return pulumi.get(self, "used")


@pulumi.output_type
class InstanceTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 type: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 标签键。
        :param builtins.str type: 标签类型。
        :param builtins.str value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def type(self) -> Optional[builtins.str]:
        """
        标签类型。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class MountPointClient(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "protocolVersion":
            suggest = "protocol_version"
        elif key == "vpcName":
            suggest = "vpc_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in MountPointClient. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        MountPointClient.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        MountPointClient.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ip: Optional[builtins.str] = None,
                 protocol_version: Optional[builtins.str] = None,
                 vpc_name: Optional[builtins.str] = None):
        """
        :param builtins.str ip: 客户端的私有网络 IP 地址。
        :param builtins.str protocol_version: 挂载协议版本号。取值：NFSv3。
        :param builtins.str vpc_name: 私有网络名称。
        """
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if protocol_version is not None:
            pulumi.set(__self__, "protocol_version", protocol_version)
        if vpc_name is not None:
            pulumi.set(__self__, "vpc_name", vpc_name)

    @property
    @pulumi.getter
    def ip(self) -> Optional[builtins.str]:
        """
        客户端的私有网络 IP 地址。
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter(name="protocolVersion")
    def protocol_version(self) -> Optional[builtins.str]:
        """
        挂载协议版本号。取值：NFSv3。
        """
        return pulumi.get(self, "protocol_version")

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> Optional[builtins.str]:
        """
        私有网络名称。
        """
        return pulumi.get(self, "vpc_name")


@pulumi.output_type
class MountPointPermissionGroup(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "createTime":
            suggest = "create_time"
        elif key == "fileSystemCount":
            suggest = "file_system_count"
        elif key == "fileSystemType":
            suggest = "file_system_type"
        elif key == "mountPoints":
            suggest = "mount_points"
        elif key == "permissionGroupName":
            suggest = "permission_group_name"
        elif key == "permissionRuleCount":
            suggest = "permission_rule_count"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in MountPointPermissionGroup. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        MountPointPermissionGroup.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        MountPointPermissionGroup.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 create_time: Optional[builtins.str] = None,
                 description: Optional[builtins.str] = None,
                 file_system_count: Optional[builtins.int] = None,
                 file_system_type: Optional[builtins.str] = None,
                 mount_points: Optional[Sequence['outputs.MountPointPermissionGroupMountPoint']] = None,
                 permission_group_name: Optional[builtins.str] = None,
                 permission_rule_count: Optional[builtins.int] = None):
        """
        :param builtins.str create_time: 权限组创建时间。
        :param builtins.str description: 权限组描述信息。
        :param builtins.int file_system_count: 关联该权限组的文件系统数量。
        :param builtins.str file_system_type: 文件系统类型。取值说明如下：Extreme：NAS 极速型。Capacity：NAS 容量型。Cache：NAS 缓存型。
        :param builtins.str permission_group_name: 权限组名称。
        :param builtins.int permission_rule_count: 权限规则数量。
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if file_system_count is not None:
            pulumi.set(__self__, "file_system_count", file_system_count)
        if file_system_type is not None:
            pulumi.set(__self__, "file_system_type", file_system_type)
        if mount_points is not None:
            pulumi.set(__self__, "mount_points", mount_points)
        if permission_group_name is not None:
            pulumi.set(__self__, "permission_group_name", permission_group_name)
        if permission_rule_count is not None:
            pulumi.set(__self__, "permission_rule_count", permission_rule_count)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[builtins.str]:
        """
        权限组创建时间。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> Optional[builtins.str]:
        """
        权限组描述信息。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="fileSystemCount")
    def file_system_count(self) -> Optional[builtins.int]:
        """
        关联该权限组的文件系统数量。
        """
        return pulumi.get(self, "file_system_count")

    @property
    @pulumi.getter(name="fileSystemType")
    def file_system_type(self) -> Optional[builtins.str]:
        """
        文件系统类型。取值说明如下：Extreme：NAS 极速型。Capacity：NAS 容量型。Cache：NAS 缓存型。
        """
        return pulumi.get(self, "file_system_type")

    @property
    @pulumi.getter(name="mountPoints")
    def mount_points(self) -> Optional[Sequence['outputs.MountPointPermissionGroupMountPoint']]:
        return pulumi.get(self, "mount_points")

    @property
    @pulumi.getter(name="permissionGroupName")
    def permission_group_name(self) -> Optional[builtins.str]:
        """
        权限组名称。
        """
        return pulumi.get(self, "permission_group_name")

    @property
    @pulumi.getter(name="permissionRuleCount")
    def permission_rule_count(self) -> Optional[builtins.int]:
        """
        权限规则数量。
        """
        return pulumi.get(self, "permission_rule_count")


@pulumi.output_type
class MountPointPermissionGroupMountPoint(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "fileSystemId":
            suggest = "file_system_id"
        elif key == "mountPointId":
            suggest = "mount_point_id"
        elif key == "mountPointName":
            suggest = "mount_point_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in MountPointPermissionGroupMountPoint. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        MountPointPermissionGroupMountPoint.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        MountPointPermissionGroupMountPoint.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 file_system_id: Optional[builtins.str] = None,
                 mount_point_id: Optional[builtins.str] = None,
                 mount_point_name: Optional[builtins.str] = None):
        """
        :param builtins.str file_system_id: 文件系统 ID。
        :param builtins.str mount_point_id: 挂载点 ID。
        :param builtins.str mount_point_name: 挂载点名称。
        """
        if file_system_id is not None:
            pulumi.set(__self__, "file_system_id", file_system_id)
        if mount_point_id is not None:
            pulumi.set(__self__, "mount_point_id", mount_point_id)
        if mount_point_name is not None:
            pulumi.set(__self__, "mount_point_name", mount_point_name)

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> Optional[builtins.str]:
        """
        文件系统 ID。
        """
        return pulumi.get(self, "file_system_id")

    @property
    @pulumi.getter(name="mountPointId")
    def mount_point_id(self) -> Optional[builtins.str]:
        """
        挂载点 ID。
        """
        return pulumi.get(self, "mount_point_id")

    @property
    @pulumi.getter(name="mountPointName")
    def mount_point_name(self) -> Optional[builtins.str]:
        """
        挂载点名称。
        """
        return pulumi.get(self, "mount_point_name")


@pulumi.output_type
class GetInstanceCachePerformanceResult(dict):
    def __init__(__self__, *,
                 cache_bandwidth: builtins.int):
        """
        :param builtins.int cache_bandwidth: 预配置带宽，用于增加文件系统带宽。
        """
        pulumi.set(__self__, "cache_bandwidth", cache_bandwidth)

    @property
    @pulumi.getter(name="cacheBandwidth")
    def cache_bandwidth(self) -> builtins.int:
        """
        预配置带宽，用于增加文件系统带宽。
        """
        return pulumi.get(self, "cache_bandwidth")


@pulumi.output_type
class GetInstanceCapacityResult(dict):
    def __init__(__self__, *,
                 total: builtins.float,
                 used: builtins.float):
        """
        :param builtins.float total: 文件系统可用总容量，单位为 GiB。
        :param builtins.float used: 文件系统已使用容量，单位为 MiB。
        """
        pulumi.set(__self__, "total", total)
        pulumi.set(__self__, "used", used)

    @property
    @pulumi.getter
    def total(self) -> builtins.float:
        """
        文件系统可用总容量，单位为 GiB。
        """
        return pulumi.get(self, "total")

    @property
    @pulumi.getter
    def used(self) -> builtins.float:
        """
        文件系统已使用容量，单位为 MiB。
        """
        return pulumi.get(self, "used")


@pulumi.output_type
class GetInstanceTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 type: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 标签键。
        :param builtins.str type: 标签类型。
        :param builtins.str value: 标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        标签类型。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetMountPointClientResult(dict):
    def __init__(__self__, *,
                 ip: builtins.str,
                 protocol_version: builtins.str,
                 vpc_name: builtins.str):
        """
        :param builtins.str ip: 客户端的私有网络 IP 地址。
        :param builtins.str protocol_version: 挂载协议版本号。取值：NFSv3。
        :param builtins.str vpc_name: 私有网络名称。
        """
        pulumi.set(__self__, "ip", ip)
        pulumi.set(__self__, "protocol_version", protocol_version)
        pulumi.set(__self__, "vpc_name", vpc_name)

    @property
    @pulumi.getter
    def ip(self) -> builtins.str:
        """
        客户端的私有网络 IP 地址。
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter(name="protocolVersion")
    def protocol_version(self) -> builtins.str:
        """
        挂载协议版本号。取值：NFSv3。
        """
        return pulumi.get(self, "protocol_version")

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> builtins.str:
        """
        私有网络名称。
        """
        return pulumi.get(self, "vpc_name")


@pulumi.output_type
class GetMountPointPermissionGroupResult(dict):
    def __init__(__self__, *,
                 create_time: builtins.str,
                 description: builtins.str,
                 file_system_count: builtins.int,
                 file_system_type: builtins.str,
                 mount_points: Sequence['outputs.GetMountPointPermissionGroupMountPointResult'],
                 permission_group_name: builtins.str,
                 permission_rule_count: builtins.int):
        """
        :param builtins.str create_time: 权限组创建时间。
        :param builtins.str description: 权限组描述信息。
        :param builtins.int file_system_count: 关联该权限组的文件系统数量。
        :param builtins.str file_system_type: 文件系统类型。取值说明如下：Extreme：NAS 极速型。Capacity：NAS 容量型。Cache：NAS 缓存型。
        :param Sequence['GetMountPointPermissionGroupMountPointArgs'] mount_points: 使用该权限组的挂载点信息。
        :param builtins.str permission_group_name: 权限组名称。
        :param builtins.int permission_rule_count: 权限规则数量。
        """
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "file_system_count", file_system_count)
        pulumi.set(__self__, "file_system_type", file_system_type)
        pulumi.set(__self__, "mount_points", mount_points)
        pulumi.set(__self__, "permission_group_name", permission_group_name)
        pulumi.set(__self__, "permission_rule_count", permission_rule_count)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        权限组创建时间。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        权限组描述信息。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="fileSystemCount")
    def file_system_count(self) -> builtins.int:
        """
        关联该权限组的文件系统数量。
        """
        return pulumi.get(self, "file_system_count")

    @property
    @pulumi.getter(name="fileSystemType")
    def file_system_type(self) -> builtins.str:
        """
        文件系统类型。取值说明如下：Extreme：NAS 极速型。Capacity：NAS 容量型。Cache：NAS 缓存型。
        """
        return pulumi.get(self, "file_system_type")

    @property
    @pulumi.getter(name="mountPoints")
    def mount_points(self) -> Sequence['outputs.GetMountPointPermissionGroupMountPointResult']:
        """
        使用该权限组的挂载点信息。
        """
        return pulumi.get(self, "mount_points")

    @property
    @pulumi.getter(name="permissionGroupName")
    def permission_group_name(self) -> builtins.str:
        """
        权限组名称。
        """
        return pulumi.get(self, "permission_group_name")

    @property
    @pulumi.getter(name="permissionRuleCount")
    def permission_rule_count(self) -> builtins.int:
        """
        权限规则数量。
        """
        return pulumi.get(self, "permission_rule_count")


@pulumi.output_type
class GetMountPointPermissionGroupMountPointResult(dict):
    def __init__(__self__, *,
                 file_system_id: builtins.str,
                 mount_point_id: builtins.str,
                 mount_point_name: builtins.str):
        """
        :param builtins.str file_system_id: 文件系统 ID。
        :param builtins.str mount_point_id: 挂载点 ID。
        :param builtins.str mount_point_name: 挂载点名称。
        """
        pulumi.set(__self__, "file_system_id", file_system_id)
        pulumi.set(__self__, "mount_point_id", mount_point_id)
        pulumi.set(__self__, "mount_point_name", mount_point_name)

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> builtins.str:
        """
        文件系统 ID。
        """
        return pulumi.get(self, "file_system_id")

    @property
    @pulumi.getter(name="mountPointId")
    def mount_point_id(self) -> builtins.str:
        """
        挂载点 ID。
        """
        return pulumi.get(self, "mount_point_id")

    @property
    @pulumi.getter(name="mountPointName")
    def mount_point_name(self) -> builtins.str:
        """
        挂载点名称。
        """
        return pulumi.get(self, "mount_point_name")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .get_kafka_trigger import *
from .get_kafka_triggers import *
from .get_sandbox import *
from .get_sandboxes import *
from .kafka_trigger import *
from .sandbox import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['BackupArgs', 'Backup']

@pulumi.input_type
class BackupArgs:
    def __init__(__self__, *,
                 instance_id: pulumi.Input[builtins.str],
                 backup_metas: Optional[pulumi.Input[Sequence[pulumi.Input['BackupBackupMetaArgs']]]] = None,
                 backup_method: Optional[pulumi.Input[builtins.str]] = None,
                 backup_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Backup resource.
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] backup_method: 备份类型，取值：Physical（物理备份）、Logical（逻辑备份）、Snapshot（快照备份）。
        :param pulumi.Input[builtins.str] backup_type: 备份方式，取值：Full（全量/库表备）、Increment（增量备份）、DumpAll（全库备份）。
        """
        pulumi.set(__self__, "instance_id", instance_id)
        if backup_metas is not None:
            pulumi.set(__self__, "backup_metas", backup_metas)
        if backup_method is not None:
            pulumi.set(__self__, "backup_method", backup_method)
        if backup_type is not None:
            pulumi.set(__self__, "backup_type", backup_type)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="backupMetas")
    def backup_metas(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BackupBackupMetaArgs']]]]:
        return pulumi.get(self, "backup_metas")

    @backup_metas.setter
    def backup_metas(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BackupBackupMetaArgs']]]]):
        pulumi.set(self, "backup_metas", value)

    @property
    @pulumi.getter(name="backupMethod")
    def backup_method(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备份类型，取值：Physical（物理备份）、Logical（逻辑备份）、Snapshot（快照备份）。
        """
        return pulumi.get(self, "backup_method")

    @backup_method.setter
    def backup_method(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "backup_method", value)

    @property
    @pulumi.getter(name="backupType")
    def backup_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备份方式，取值：Full（全量/库表备）、Increment（增量备份）、DumpAll（全库备份）。
        """
        return pulumi.get(self, "backup_type")

    @backup_type.setter
    def backup_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "backup_type", value)


@pulumi.input_type
class _BackupState:
    def __init__(__self__, *,
                 backup_end_time: Optional[pulumi.Input[builtins.str]] = None,
                 backup_file_name: Optional[pulumi.Input[builtins.str]] = None,
                 backup_file_size: Optional[pulumi.Input[builtins.int]] = None,
                 backup_id: Optional[pulumi.Input[builtins.str]] = None,
                 backup_metas: Optional[pulumi.Input[Sequence[pulumi.Input['BackupBackupMetaArgs']]]] = None,
                 backup_method: Optional[pulumi.Input[builtins.str]] = None,
                 backup_name: Optional[pulumi.Input[builtins.str]] = None,
                 backup_region: Optional[pulumi.Input[builtins.str]] = None,
                 backup_start_time: Optional[pulumi.Input[builtins.str]] = None,
                 backup_status: Optional[pulumi.Input[builtins.str]] = None,
                 backup_type: Optional[pulumi.Input[builtins.str]] = None,
                 consistent_time: Optional[pulumi.Input[builtins.str]] = None,
                 create_type: Optional[pulumi.Input[builtins.str]] = None,
                 db_engine_version: Optional[pulumi.Input[builtins.str]] = None,
                 db_table_infos: Optional[pulumi.Input[Sequence[pulumi.Input['BackupDbTableInfoArgs']]]] = None,
                 download_status: Optional[pulumi.Input[builtins.str]] = None,
                 engine_type: Optional[pulumi.Input[builtins.str]] = None,
                 error_message: Optional[pulumi.Input[builtins.str]] = None,
                 expired_time: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 is_encrypted: Optional[pulumi.Input[builtins.bool]] = None,
                 is_expired: Optional[pulumi.Input[builtins.bool]] = None):
        """
        Input properties used for looking up and filtering Backup resources.
        :param pulumi.Input[builtins.str] backup_end_time: 备份创建结束时间（UTC）。
        :param pulumi.Input[builtins.str] backup_file_name: 备份文件名。
        :param pulumi.Input[builtins.int] backup_file_size: 备份文件大小，单位为字节。
        :param pulumi.Input[builtins.str] backup_id: 备份 ID。
        :param pulumi.Input[builtins.str] backup_method: 备份类型，取值：Physical（物理备份）、Logical（逻辑备份）、Snapshot（快照备份）。
        :param pulumi.Input[builtins.str] backup_name: 备份的名称。
        :param pulumi.Input[builtins.str] backup_region: 备份所在区域。
        :param pulumi.Input[builtins.str] backup_start_time: 备份创建开始时间（UTC）。
        :param pulumi.Input[builtins.str] backup_status: 备份状态，取值：Success（成功）、Failed（失败）、Running（执行中）。
        :param pulumi.Input[builtins.str] backup_type: 备份方式，取值：Full（全量/库表备）、Increment（增量备份）、DumpAll（全库备份）。
        :param pulumi.Input[builtins.str] consistent_time: 一致性时间点。
        :param pulumi.Input[builtins.str] create_type: 备份创建者，取值：System（系统）、User（用户）。
        :param pulumi.Input[builtins.str] db_engine_version: 兼容版本。取值：MySQL*5*7：MySQL 5.7 版本。MySQL*8*0：MySQL 8.0 版本。
        :param pulumi.Input[builtins.str] download_status: 下载状态。
        :param pulumi.Input[builtins.str] engine_type: 数据库引擎类型。取值：InnoDB：InnoDB 引擎。RocksDB：RocksDB 引擎。
        :param pulumi.Input[builtins.str] error_message: 备份失败的错误信息。
        :param pulumi.Input[builtins.str] expired_time: 备份过期时间（UTC）。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.bool] is_encrypted: 是否加密。
        :param pulumi.Input[builtins.bool] is_expired: 是否已过期。
        """
        if backup_end_time is not None:
            pulumi.set(__self__, "backup_end_time", backup_end_time)
        if backup_file_name is not None:
            pulumi.set(__self__, "backup_file_name", backup_file_name)
        if backup_file_size is not None:
            pulumi.set(__self__, "backup_file_size", backup_file_size)
        if backup_id is not None:
            pulumi.set(__self__, "backup_id", backup_id)
        if backup_metas is not None:
            pulumi.set(__self__, "backup_metas", backup_metas)
        if backup_method is not None:
            pulumi.set(__self__, "backup_method", backup_method)
        if backup_name is not None:
            pulumi.set(__self__, "backup_name", backup_name)
        if backup_region is not None:
            pulumi.set(__self__, "backup_region", backup_region)
        if backup_start_time is not None:
            pulumi.set(__self__, "backup_start_time", backup_start_time)
        if backup_status is not None:
            pulumi.set(__self__, "backup_status", backup_status)
        if backup_type is not None:
            pulumi.set(__self__, "backup_type", backup_type)
        if consistent_time is not None:
            pulumi.set(__self__, "consistent_time", consistent_time)
        if create_type is not None:
            pulumi.set(__self__, "create_type", create_type)
        if db_engine_version is not None:
            pulumi.set(__self__, "db_engine_version", db_engine_version)
        if db_table_infos is not None:
            pulumi.set(__self__, "db_table_infos", db_table_infos)
        if download_status is not None:
            pulumi.set(__self__, "download_status", download_status)
        if engine_type is not None:
            pulumi.set(__self__, "engine_type", engine_type)
        if error_message is not None:
            pulumi.set(__self__, "error_message", error_message)
        if expired_time is not None:
            pulumi.set(__self__, "expired_time", expired_time)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if is_encrypted is not None:
            pulumi.set(__self__, "is_encrypted", is_encrypted)
        if is_expired is not None:
            pulumi.set(__self__, "is_expired", is_expired)

    @property
    @pulumi.getter(name="backupEndTime")
    def backup_end_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备份创建结束时间（UTC）。
        """
        return pulumi.get(self, "backup_end_time")

    @backup_end_time.setter
    def backup_end_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "backup_end_time", value)

    @property
    @pulumi.getter(name="backupFileName")
    def backup_file_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备份文件名。
        """
        return pulumi.get(self, "backup_file_name")

    @backup_file_name.setter
    def backup_file_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "backup_file_name", value)

    @property
    @pulumi.getter(name="backupFileSize")
    def backup_file_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        备份文件大小，单位为字节。
        """
        return pulumi.get(self, "backup_file_size")

    @backup_file_size.setter
    def backup_file_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "backup_file_size", value)

    @property
    @pulumi.getter(name="backupId")
    def backup_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备份 ID。
        """
        return pulumi.get(self, "backup_id")

    @backup_id.setter
    def backup_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "backup_id", value)

    @property
    @pulumi.getter(name="backupMetas")
    def backup_metas(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BackupBackupMetaArgs']]]]:
        return pulumi.get(self, "backup_metas")

    @backup_metas.setter
    def backup_metas(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BackupBackupMetaArgs']]]]):
        pulumi.set(self, "backup_metas", value)

    @property
    @pulumi.getter(name="backupMethod")
    def backup_method(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备份类型，取值：Physical（物理备份）、Logical（逻辑备份）、Snapshot（快照备份）。
        """
        return pulumi.get(self, "backup_method")

    @backup_method.setter
    def backup_method(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "backup_method", value)

    @property
    @pulumi.getter(name="backupName")
    def backup_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备份的名称。
        """
        return pulumi.get(self, "backup_name")

    @backup_name.setter
    def backup_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "backup_name", value)

    @property
    @pulumi.getter(name="backupRegion")
    def backup_region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备份所在区域。
        """
        return pulumi.get(self, "backup_region")

    @backup_region.setter
    def backup_region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "backup_region", value)

    @property
    @pulumi.getter(name="backupStartTime")
    def backup_start_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备份创建开始时间（UTC）。
        """
        return pulumi.get(self, "backup_start_time")

    @backup_start_time.setter
    def backup_start_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "backup_start_time", value)

    @property
    @pulumi.getter(name="backupStatus")
    def backup_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备份状态，取值：Success（成功）、Failed（失败）、Running（执行中）。
        """
        return pulumi.get(self, "backup_status")

    @backup_status.setter
    def backup_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "backup_status", value)

    @property
    @pulumi.getter(name="backupType")
    def backup_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备份方式，取值：Full（全量/库表备）、Increment（增量备份）、DumpAll（全库备份）。
        """
        return pulumi.get(self, "backup_type")

    @backup_type.setter
    def backup_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "backup_type", value)

    @property
    @pulumi.getter(name="consistentTime")
    def consistent_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        一致性时间点。
        """
        return pulumi.get(self, "consistent_time")

    @consistent_time.setter
    def consistent_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "consistent_time", value)

    @property
    @pulumi.getter(name="createType")
    def create_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备份创建者，取值：System（系统）、User（用户）。
        """
        return pulumi.get(self, "create_type")

    @create_type.setter
    def create_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_type", value)

    @property
    @pulumi.getter(name="dbEngineVersion")
    def db_engine_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        兼容版本。取值：MySQL*5*7：MySQL 5.7 版本。MySQL*8*0：MySQL 8.0 版本。
        """
        return pulumi.get(self, "db_engine_version")

    @db_engine_version.setter
    def db_engine_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "db_engine_version", value)

    @property
    @pulumi.getter(name="dbTableInfos")
    def db_table_infos(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BackupDbTableInfoArgs']]]]:
        return pulumi.get(self, "db_table_infos")

    @db_table_infos.setter
    def db_table_infos(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BackupDbTableInfoArgs']]]]):
        pulumi.set(self, "db_table_infos", value)

    @property
    @pulumi.getter(name="downloadStatus")
    def download_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        下载状态。
        """
        return pulumi.get(self, "download_status")

    @download_status.setter
    def download_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "download_status", value)

    @property
    @pulumi.getter(name="engineType")
    def engine_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        数据库引擎类型。取值：InnoDB：InnoDB 引擎。RocksDB：RocksDB 引擎。
        """
        return pulumi.get(self, "engine_type")

    @engine_type.setter
    def engine_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "engine_type", value)

    @property
    @pulumi.getter(name="errorMessage")
    def error_message(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备份失败的错误信息。
        """
        return pulumi.get(self, "error_message")

    @error_message.setter
    def error_message(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "error_message", value)

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备份过期时间（UTC）。
        """
        return pulumi.get(self, "expired_time")

    @expired_time.setter
    def expired_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expired_time", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="isEncrypted")
    def is_encrypted(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否加密。
        """
        return pulumi.get(self, "is_encrypted")

    @is_encrypted.setter
    def is_encrypted(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_encrypted", value)

    @property
    @pulumi.getter(name="isExpired")
    def is_expired(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否已过期。
        """
        return pulumi.get(self, "is_expired")

    @is_expired.setter
    def is_expired(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_expired", value)


@pulumi.type_token("bytepluscc:rdsmysql/backup:Backup")
class Backup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backup_metas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BackupBackupMetaArgs', 'BackupBackupMetaArgsDict']]]]] = None,
                 backup_method: Optional[pulumi.Input[builtins.str]] = None,
                 backup_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        备份是数据库的重要运行时文件，基于备份文件，数据库能够实现容灾、恢复等功能。云数据库 MySQL 版提供了数据备份和日志备份两种备份能力：通过数据备份可将数据库恢复至某个备份集，通过日志备份可将数据库恢复至指定时间点。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        rdsmysqlbackup_demo = bytepluscc.rdsmysql.Backup("rdsmysqlbackupDemo",
            instance_id="mysql-9e2c59****",
            backup_method="Logical",
            backup_metas=[{
                "database": "test",
                "tables": [],
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdsmysql/backup:Backup example "instance_id|backup_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] backup_method: 备份类型，取值：Physical（物理备份）、Logical（逻辑备份）、Snapshot（快照备份）。
        :param pulumi.Input[builtins.str] backup_type: 备份方式，取值：Full（全量/库表备）、Increment（增量备份）、DumpAll（全库备份）。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BackupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        备份是数据库的重要运行时文件，基于备份文件，数据库能够实现容灾、恢复等功能。云数据库 MySQL 版提供了数据备份和日志备份两种备份能力：通过数据备份可将数据库恢复至某个备份集，通过日志备份可将数据库恢复至指定时间点。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        rdsmysqlbackup_demo = bytepluscc.rdsmysql.Backup("rdsmysqlbackupDemo",
            instance_id="mysql-9e2c59****",
            backup_method="Logical",
            backup_metas=[{
                "database": "test",
                "tables": [],
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdsmysql/backup:Backup example "instance_id|backup_id"
        ```

        :param str resource_name: The name of the resource.
        :param BackupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BackupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backup_metas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BackupBackupMetaArgs', 'BackupBackupMetaArgsDict']]]]] = None,
                 backup_method: Optional[pulumi.Input[builtins.str]] = None,
                 backup_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BackupArgs.__new__(BackupArgs)

            __props__.__dict__["backup_metas"] = backup_metas
            __props__.__dict__["backup_method"] = backup_method
            __props__.__dict__["backup_type"] = backup_type
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["backup_end_time"] = None
            __props__.__dict__["backup_file_name"] = None
            __props__.__dict__["backup_file_size"] = None
            __props__.__dict__["backup_id"] = None
            __props__.__dict__["backup_name"] = None
            __props__.__dict__["backup_region"] = None
            __props__.__dict__["backup_start_time"] = None
            __props__.__dict__["backup_status"] = None
            __props__.__dict__["consistent_time"] = None
            __props__.__dict__["create_type"] = None
            __props__.__dict__["db_engine_version"] = None
            __props__.__dict__["db_table_infos"] = None
            __props__.__dict__["download_status"] = None
            __props__.__dict__["engine_type"] = None
            __props__.__dict__["error_message"] = None
            __props__.__dict__["expired_time"] = None
            __props__.__dict__["is_encrypted"] = None
            __props__.__dict__["is_expired"] = None
        super(Backup, __self__).__init__(
            'bytepluscc:rdsmysql/backup:Backup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            backup_end_time: Optional[pulumi.Input[builtins.str]] = None,
            backup_file_name: Optional[pulumi.Input[builtins.str]] = None,
            backup_file_size: Optional[pulumi.Input[builtins.int]] = None,
            backup_id: Optional[pulumi.Input[builtins.str]] = None,
            backup_metas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BackupBackupMetaArgs', 'BackupBackupMetaArgsDict']]]]] = None,
            backup_method: Optional[pulumi.Input[builtins.str]] = None,
            backup_name: Optional[pulumi.Input[builtins.str]] = None,
            backup_region: Optional[pulumi.Input[builtins.str]] = None,
            backup_start_time: Optional[pulumi.Input[builtins.str]] = None,
            backup_status: Optional[pulumi.Input[builtins.str]] = None,
            backup_type: Optional[pulumi.Input[builtins.str]] = None,
            consistent_time: Optional[pulumi.Input[builtins.str]] = None,
            create_type: Optional[pulumi.Input[builtins.str]] = None,
            db_engine_version: Optional[pulumi.Input[builtins.str]] = None,
            db_table_infos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BackupDbTableInfoArgs', 'BackupDbTableInfoArgsDict']]]]] = None,
            download_status: Optional[pulumi.Input[builtins.str]] = None,
            engine_type: Optional[pulumi.Input[builtins.str]] = None,
            error_message: Optional[pulumi.Input[builtins.str]] = None,
            expired_time: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            is_encrypted: Optional[pulumi.Input[builtins.bool]] = None,
            is_expired: Optional[pulumi.Input[builtins.bool]] = None) -> 'Backup':
        """
        Get an existing Backup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] backup_end_time: 备份创建结束时间（UTC）。
        :param pulumi.Input[builtins.str] backup_file_name: 备份文件名。
        :param pulumi.Input[builtins.int] backup_file_size: 备份文件大小，单位为字节。
        :param pulumi.Input[builtins.str] backup_id: 备份 ID。
        :param pulumi.Input[builtins.str] backup_method: 备份类型，取值：Physical（物理备份）、Logical（逻辑备份）、Snapshot（快照备份）。
        :param pulumi.Input[builtins.str] backup_name: 备份的名称。
        :param pulumi.Input[builtins.str] backup_region: 备份所在区域。
        :param pulumi.Input[builtins.str] backup_start_time: 备份创建开始时间（UTC）。
        :param pulumi.Input[builtins.str] backup_status: 备份状态，取值：Success（成功）、Failed（失败）、Running（执行中）。
        :param pulumi.Input[builtins.str] backup_type: 备份方式，取值：Full（全量/库表备）、Increment（增量备份）、DumpAll（全库备份）。
        :param pulumi.Input[builtins.str] consistent_time: 一致性时间点。
        :param pulumi.Input[builtins.str] create_type: 备份创建者，取值：System（系统）、User（用户）。
        :param pulumi.Input[builtins.str] db_engine_version: 兼容版本。取值：MySQL*5*7：MySQL 5.7 版本。MySQL*8*0：MySQL 8.0 版本。
        :param pulumi.Input[builtins.str] download_status: 下载状态。
        :param pulumi.Input[builtins.str] engine_type: 数据库引擎类型。取值：InnoDB：InnoDB 引擎。RocksDB：RocksDB 引擎。
        :param pulumi.Input[builtins.str] error_message: 备份失败的错误信息。
        :param pulumi.Input[builtins.str] expired_time: 备份过期时间（UTC）。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.bool] is_encrypted: 是否加密。
        :param pulumi.Input[builtins.bool] is_expired: 是否已过期。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BackupState.__new__(_BackupState)

        __props__.__dict__["backup_end_time"] = backup_end_time
        __props__.__dict__["backup_file_name"] = backup_file_name
        __props__.__dict__["backup_file_size"] = backup_file_size
        __props__.__dict__["backup_id"] = backup_id
        __props__.__dict__["backup_metas"] = backup_metas
        __props__.__dict__["backup_method"] = backup_method
        __props__.__dict__["backup_name"] = backup_name
        __props__.__dict__["backup_region"] = backup_region
        __props__.__dict__["backup_start_time"] = backup_start_time
        __props__.__dict__["backup_status"] = backup_status
        __props__.__dict__["backup_type"] = backup_type
        __props__.__dict__["consistent_time"] = consistent_time
        __props__.__dict__["create_type"] = create_type
        __props__.__dict__["db_engine_version"] = db_engine_version
        __props__.__dict__["db_table_infos"] = db_table_infos
        __props__.__dict__["download_status"] = download_status
        __props__.__dict__["engine_type"] = engine_type
        __props__.__dict__["error_message"] = error_message
        __props__.__dict__["expired_time"] = expired_time
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["is_encrypted"] = is_encrypted
        __props__.__dict__["is_expired"] = is_expired
        return Backup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="backupEndTime")
    def backup_end_time(self) -> pulumi.Output[builtins.str]:
        """
        备份创建结束时间（UTC）。
        """
        return pulumi.get(self, "backup_end_time")

    @property
    @pulumi.getter(name="backupFileName")
    def backup_file_name(self) -> pulumi.Output[builtins.str]:
        """
        备份文件名。
        """
        return pulumi.get(self, "backup_file_name")

    @property
    @pulumi.getter(name="backupFileSize")
    def backup_file_size(self) -> pulumi.Output[builtins.int]:
        """
        备份文件大小，单位为字节。
        """
        return pulumi.get(self, "backup_file_size")

    @property
    @pulumi.getter(name="backupId")
    def backup_id(self) -> pulumi.Output[builtins.str]:
        """
        备份 ID。
        """
        return pulumi.get(self, "backup_id")

    @property
    @pulumi.getter(name="backupMetas")
    def backup_metas(self) -> pulumi.Output[Sequence['outputs.BackupBackupMeta']]:
        return pulumi.get(self, "backup_metas")

    @property
    @pulumi.getter(name="backupMethod")
    def backup_method(self) -> pulumi.Output[builtins.str]:
        """
        备份类型，取值：Physical（物理备份）、Logical（逻辑备份）、Snapshot（快照备份）。
        """
        return pulumi.get(self, "backup_method")

    @property
    @pulumi.getter(name="backupName")
    def backup_name(self) -> pulumi.Output[builtins.str]:
        """
        备份的名称。
        """
        return pulumi.get(self, "backup_name")

    @property
    @pulumi.getter(name="backupRegion")
    def backup_region(self) -> pulumi.Output[builtins.str]:
        """
        备份所在区域。
        """
        return pulumi.get(self, "backup_region")

    @property
    @pulumi.getter(name="backupStartTime")
    def backup_start_time(self) -> pulumi.Output[builtins.str]:
        """
        备份创建开始时间（UTC）。
        """
        return pulumi.get(self, "backup_start_time")

    @property
    @pulumi.getter(name="backupStatus")
    def backup_status(self) -> pulumi.Output[builtins.str]:
        """
        备份状态，取值：Success（成功）、Failed（失败）、Running（执行中）。
        """
        return pulumi.get(self, "backup_status")

    @property
    @pulumi.getter(name="backupType")
    def backup_type(self) -> pulumi.Output[builtins.str]:
        """
        备份方式，取值：Full（全量/库表备）、Increment（增量备份）、DumpAll（全库备份）。
        """
        return pulumi.get(self, "backup_type")

    @property
    @pulumi.getter(name="consistentTime")
    def consistent_time(self) -> pulumi.Output[builtins.str]:
        """
        一致性时间点。
        """
        return pulumi.get(self, "consistent_time")

    @property
    @pulumi.getter(name="createType")
    def create_type(self) -> pulumi.Output[builtins.str]:
        """
        备份创建者，取值：System（系统）、User（用户）。
        """
        return pulumi.get(self, "create_type")

    @property
    @pulumi.getter(name="dbEngineVersion")
    def db_engine_version(self) -> pulumi.Output[builtins.str]:
        """
        兼容版本。取值：MySQL*5*7：MySQL 5.7 版本。MySQL*8*0：MySQL 8.0 版本。
        """
        return pulumi.get(self, "db_engine_version")

    @property
    @pulumi.getter(name="dbTableInfos")
    def db_table_infos(self) -> pulumi.Output[Sequence['outputs.BackupDbTableInfo']]:
        return pulumi.get(self, "db_table_infos")

    @property
    @pulumi.getter(name="downloadStatus")
    def download_status(self) -> pulumi.Output[builtins.str]:
        """
        下载状态。
        """
        return pulumi.get(self, "download_status")

    @property
    @pulumi.getter(name="engineType")
    def engine_type(self) -> pulumi.Output[builtins.str]:
        """
        数据库引擎类型。取值：InnoDB：InnoDB 引擎。RocksDB：RocksDB 引擎。
        """
        return pulumi.get(self, "engine_type")

    @property
    @pulumi.getter(name="errorMessage")
    def error_message(self) -> pulumi.Output[builtins.str]:
        """
        备份失败的错误信息。
        """
        return pulumi.get(self, "error_message")

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> pulumi.Output[builtins.str]:
        """
        备份过期时间（UTC）。
        """
        return pulumi.get(self, "expired_time")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="isEncrypted")
    def is_encrypted(self) -> pulumi.Output[builtins.bool]:
        """
        是否加密。
        """
        return pulumi.get(self, "is_encrypted")

    @property
    @pulumi.getter(name="isExpired")
    def is_expired(self) -> pulumi.Output[builtins.bool]:
        """
        是否已过期。
        """
        return pulumi.get(self, "is_expired")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['Ipv6AddressBandwidthArgs', 'Ipv6AddressBandwidth']

@pulumi.input_type
class Ipv6AddressBandwidthArgs:
    def __init__(__self__, *,
                 billing_type: pulumi.Input[builtins.int],
                 ipv6_address: pulumi.Input[builtins.str],
                 bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['Ipv6AddressBandwidthTagArgs']]]] = None):
        """
        The set of arguments for constructing a Ipv6AddressBandwidth resource.
        :param pulumi.Input[builtins.int] billing_type: IPv6公网带宽的计费类型。2：按量计费-按带宽上限计费。3：按量计费-按实际流量计费。
        :param pulumi.Input[builtins.str] ipv6_address: IPv6地址。
        :param pulumi.Input[builtins.int] bandwidth: IPv6公网带宽的带宽上限。
        :param pulumi.Input[builtins.str] bandwidth_package_id: IPv6共享带宽包的ID。
        :param pulumi.Input[builtins.str] project_name: IPv6公网带宽的项目。
        """
        pulumi.set(__self__, "billing_type", billing_type)
        pulumi.set(__self__, "ipv6_address", ipv6_address)
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if bandwidth_package_id is not None:
            pulumi.set(__self__, "bandwidth_package_id", bandwidth_package_id)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> pulumi.Input[builtins.int]:
        """
        IPv6公网带宽的计费类型。2：按量计费-按带宽上限计费。3：按量计费-按实际流量计费。
        """
        return pulumi.get(self, "billing_type")

    @billing_type.setter
    def billing_type(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "billing_type", value)

    @property
    @pulumi.getter(name="ipv6Address")
    def ipv6_address(self) -> pulumi.Input[builtins.str]:
        """
        IPv6地址。
        """
        return pulumi.get(self, "ipv6_address")

    @ipv6_address.setter
    def ipv6_address(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "ipv6_address", value)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        IPv6公网带宽的带宽上限。
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="bandwidthPackageId")
    def bandwidth_package_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv6共享带宽包的ID。
        """
        return pulumi.get(self, "bandwidth_package_id")

    @bandwidth_package_id.setter
    def bandwidth_package_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "bandwidth_package_id", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv6公网带宽的项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['Ipv6AddressBandwidthTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['Ipv6AddressBandwidthTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _Ipv6AddressBandwidthState:
    def __init__(__self__, *,
                 allocation_id: Optional[pulumi.Input[builtins.str]] = None,
                 bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 business_status: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 deleted_time: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_address: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 isp: Optional[pulumi.Input[builtins.str]] = None,
                 lock_reason: Optional[pulumi.Input[builtins.str]] = None,
                 network_type: Optional[pulumi.Input[builtins.str]] = None,
                 overdue_time: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 service_managed: Optional[pulumi.Input[builtins.bool]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['Ipv6AddressBandwidthTagArgs']]]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Ipv6AddressBandwidth resources.
        :param pulumi.Input[builtins.str] allocation_id: IPv6公网带宽的ID。
        :param pulumi.Input[builtins.int] bandwidth: IPv6公网带宽的带宽上限。
        :param pulumi.Input[builtins.str] bandwidth_package_id: IPv6共享带宽包的ID。
        :param pulumi.Input[builtins.int] billing_type: IPv6公网带宽的计费类型。2：按量计费-按带宽上限计费。3：按量计费-按实际流量计费。
        :param pulumi.Input[builtins.str] business_status: IPv6公网带宽是否被锁定。Normal：正常。FinancialLocked：被锁定。
        :param pulumi.Input[builtins.str] created_time: IPv6公网带宽的开通时间。
        :param pulumi.Input[builtins.str] deleted_time: IPv6公网带宽的删除时间。
        :param pulumi.Input[builtins.str] instance_id: IPv6公网带宽关联的实例ID。
        :param pulumi.Input[builtins.str] instance_type: IPv6公网带宽关联的实例类型。EcsInstance：云服务器实例。ClbInstance：负载均衡。
        :param pulumi.Input[builtins.str] ipv6_address: IPv6地址。
        :param pulumi.Input[builtins.str] ipv6_gateway_id: IPv6网关的ID。
        :param pulumi.Input[builtins.str] isp: IPv6公网带宽的线路类型。BGP：BGP（多线）。
        :param pulumi.Input[builtins.str] lock_reason: IPv6公网带宽被锁定的原因。该参数只有IPv6公网带宽处于FinancialLocked状态时才有返回值。Financial：因欠费被锁定。Security：因安全被锁定。
        :param pulumi.Input[builtins.str] network_type: IPv6地址的通信类型。Private：私网通信类型。Public：公网通信类型。
        :param pulumi.Input[builtins.str] overdue_time: IPv6公网带宽欠费关停的时间。
        :param pulumi.Input[builtins.str] project_name: IPv6公网带宽的项目。
        :param pulumi.Input[builtins.bool] service_managed: 是否为服务托管。
        :param pulumi.Input[builtins.str] status: IPv6公网带宽的状态。Creating：创建中。Available：可用。
        :param pulumi.Input[builtins.str] updated_time: IPv6公网带宽的最近操作时间。
        """
        if allocation_id is not None:
            pulumi.set(__self__, "allocation_id", allocation_id)
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if bandwidth_package_id is not None:
            pulumi.set(__self__, "bandwidth_package_id", bandwidth_package_id)
        if billing_type is not None:
            pulumi.set(__self__, "billing_type", billing_type)
        if business_status is not None:
            pulumi.set(__self__, "business_status", business_status)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if deleted_time is not None:
            pulumi.set(__self__, "deleted_time", deleted_time)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if ipv6_address is not None:
            pulumi.set(__self__, "ipv6_address", ipv6_address)
        if ipv6_gateway_id is not None:
            pulumi.set(__self__, "ipv6_gateway_id", ipv6_gateway_id)
        if isp is not None:
            pulumi.set(__self__, "isp", isp)
        if lock_reason is not None:
            pulumi.set(__self__, "lock_reason", lock_reason)
        if network_type is not None:
            pulumi.set(__self__, "network_type", network_type)
        if overdue_time is not None:
            pulumi.set(__self__, "overdue_time", overdue_time)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if service_managed is not None:
            pulumi.set(__self__, "service_managed", service_managed)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="allocationId")
    def allocation_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv6公网带宽的ID。
        """
        return pulumi.get(self, "allocation_id")

    @allocation_id.setter
    def allocation_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allocation_id", value)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        IPv6公网带宽的带宽上限。
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="bandwidthPackageId")
    def bandwidth_package_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv6共享带宽包的ID。
        """
        return pulumi.get(self, "bandwidth_package_id")

    @bandwidth_package_id.setter
    def bandwidth_package_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "bandwidth_package_id", value)

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        IPv6公网带宽的计费类型。2：按量计费-按带宽上限计费。3：按量计费-按实际流量计费。
        """
        return pulumi.get(self, "billing_type")

    @billing_type.setter
    def billing_type(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "billing_type", value)

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv6公网带宽是否被锁定。Normal：正常。FinancialLocked：被锁定。
        """
        return pulumi.get(self, "business_status")

    @business_status.setter
    def business_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "business_status", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv6公网带宽的开通时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv6公网带宽的删除时间。
        """
        return pulumi.get(self, "deleted_time")

    @deleted_time.setter
    def deleted_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deleted_time", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv6公网带宽关联的实例ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv6公网带宽关联的实例类型。EcsInstance：云服务器实例。ClbInstance：负载均衡。
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="ipv6Address")
    def ipv6_address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv6地址。
        """
        return pulumi.get(self, "ipv6_address")

    @ipv6_address.setter
    def ipv6_address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv6_address", value)

    @property
    @pulumi.getter(name="ipv6GatewayId")
    def ipv6_gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv6网关的ID。
        """
        return pulumi.get(self, "ipv6_gateway_id")

    @ipv6_gateway_id.setter
    def ipv6_gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv6_gateway_id", value)

    @property
    @pulumi.getter
    def isp(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv6公网带宽的线路类型。BGP：BGP（多线）。
        """
        return pulumi.get(self, "isp")

    @isp.setter
    def isp(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "isp", value)

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv6公网带宽被锁定的原因。该参数只有IPv6公网带宽处于FinancialLocked状态时才有返回值。Financial：因欠费被锁定。Security：因安全被锁定。
        """
        return pulumi.get(self, "lock_reason")

    @lock_reason.setter
    def lock_reason(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "lock_reason", value)

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv6地址的通信类型。Private：私网通信类型。Public：公网通信类型。
        """
        return pulumi.get(self, "network_type")

    @network_type.setter
    def network_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_type", value)

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv6公网带宽欠费关停的时间。
        """
        return pulumi.get(self, "overdue_time")

    @overdue_time.setter
    def overdue_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "overdue_time", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv6公网带宽的项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="serviceManaged")
    def service_managed(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否为服务托管。
        """
        return pulumi.get(self, "service_managed")

    @service_managed.setter
    def service_managed(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "service_managed", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv6公网带宽的状态。Creating：创建中。Available：可用。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['Ipv6AddressBandwidthTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['Ipv6AddressBandwidthTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv6公网带宽的最近操作时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:vpc/ipv6AddressBandwidth:Ipv6AddressBandwidth")
class Ipv6AddressBandwidth(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 ipv6_address: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['Ipv6AddressBandwidthTagArgs', 'Ipv6AddressBandwidthTagArgsDict']]]]] = None,
                 __props__=None):
        """
        IPv6公网流量的带宽，决定IPv6地址的公网通信能力。IPv6地址若未开通IPv6公网带宽，则仅支持私网互通，您可以按需为IPv6地址开通IPv6公网带宽，使该IPv6地址具备与公网互通的能力。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        v_pc_ipv6_address_bandwidth_demo = bytepluscc.vpc.Ipv6AddressBandwidth("VPCIpv6AddressBandwidthDemo",
            bandwidth=200,
            billing_type=2,
            ipv6_address="2406:d440:10a:****:92b:****:90b6:4f09",
            project_name="default",
            bandwidth_package_id="bwp-1vm41dmikjr451j8exxxxx",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/ipv6AddressBandwidth:Ipv6AddressBandwidth example "allocation_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] bandwidth: IPv6公网带宽的带宽上限。
        :param pulumi.Input[builtins.str] bandwidth_package_id: IPv6共享带宽包的ID。
        :param pulumi.Input[builtins.int] billing_type: IPv6公网带宽的计费类型。2：按量计费-按带宽上限计费。3：按量计费-按实际流量计费。
        :param pulumi.Input[builtins.str] ipv6_address: IPv6地址。
        :param pulumi.Input[builtins.str] project_name: IPv6公网带宽的项目。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Ipv6AddressBandwidthArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        IPv6公网流量的带宽，决定IPv6地址的公网通信能力。IPv6地址若未开通IPv6公网带宽，则仅支持私网互通，您可以按需为IPv6地址开通IPv6公网带宽，使该IPv6地址具备与公网互通的能力。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        v_pc_ipv6_address_bandwidth_demo = bytepluscc.vpc.Ipv6AddressBandwidth("VPCIpv6AddressBandwidthDemo",
            bandwidth=200,
            billing_type=2,
            ipv6_address="2406:d440:10a:****:92b:****:90b6:4f09",
            project_name="default",
            bandwidth_package_id="bwp-1vm41dmikjr451j8exxxxx",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/ipv6AddressBandwidth:Ipv6AddressBandwidth example "allocation_id"
        ```

        :param str resource_name: The name of the resource.
        :param Ipv6AddressBandwidthArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(Ipv6AddressBandwidthArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 ipv6_address: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['Ipv6AddressBandwidthTagArgs', 'Ipv6AddressBandwidthTagArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = Ipv6AddressBandwidthArgs.__new__(Ipv6AddressBandwidthArgs)

            __props__.__dict__["bandwidth"] = bandwidth
            __props__.__dict__["bandwidth_package_id"] = bandwidth_package_id
            if billing_type is None and not opts.urn:
                raise TypeError("Missing required property 'billing_type'")
            __props__.__dict__["billing_type"] = billing_type
            if ipv6_address is None and not opts.urn:
                raise TypeError("Missing required property 'ipv6_address'")
            __props__.__dict__["ipv6_address"] = ipv6_address
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["allocation_id"] = None
            __props__.__dict__["business_status"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["deleted_time"] = None
            __props__.__dict__["instance_id"] = None
            __props__.__dict__["instance_type"] = None
            __props__.__dict__["ipv6_gateway_id"] = None
            __props__.__dict__["isp"] = None
            __props__.__dict__["lock_reason"] = None
            __props__.__dict__["network_type"] = None
            __props__.__dict__["overdue_time"] = None
            __props__.__dict__["service_managed"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_time"] = None
        super(Ipv6AddressBandwidth, __self__).__init__(
            'bytepluscc:vpc/ipv6AddressBandwidth:Ipv6AddressBandwidth',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allocation_id: Optional[pulumi.Input[builtins.str]] = None,
            bandwidth: Optional[pulumi.Input[builtins.int]] = None,
            bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
            billing_type: Optional[pulumi.Input[builtins.int]] = None,
            business_status: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            deleted_time: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            instance_type: Optional[pulumi.Input[builtins.str]] = None,
            ipv6_address: Optional[pulumi.Input[builtins.str]] = None,
            ipv6_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
            isp: Optional[pulumi.Input[builtins.str]] = None,
            lock_reason: Optional[pulumi.Input[builtins.str]] = None,
            network_type: Optional[pulumi.Input[builtins.str]] = None,
            overdue_time: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            service_managed: Optional[pulumi.Input[builtins.bool]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['Ipv6AddressBandwidthTagArgs', 'Ipv6AddressBandwidthTagArgsDict']]]]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'Ipv6AddressBandwidth':
        """
        Get an existing Ipv6AddressBandwidth resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] allocation_id: IPv6公网带宽的ID。
        :param pulumi.Input[builtins.int] bandwidth: IPv6公网带宽的带宽上限。
        :param pulumi.Input[builtins.str] bandwidth_package_id: IPv6共享带宽包的ID。
        :param pulumi.Input[builtins.int] billing_type: IPv6公网带宽的计费类型。2：按量计费-按带宽上限计费。3：按量计费-按实际流量计费。
        :param pulumi.Input[builtins.str] business_status: IPv6公网带宽是否被锁定。Normal：正常。FinancialLocked：被锁定。
        :param pulumi.Input[builtins.str] created_time: IPv6公网带宽的开通时间。
        :param pulumi.Input[builtins.str] deleted_time: IPv6公网带宽的删除时间。
        :param pulumi.Input[builtins.str] instance_id: IPv6公网带宽关联的实例ID。
        :param pulumi.Input[builtins.str] instance_type: IPv6公网带宽关联的实例类型。EcsInstance：云服务器实例。ClbInstance：负载均衡。
        :param pulumi.Input[builtins.str] ipv6_address: IPv6地址。
        :param pulumi.Input[builtins.str] ipv6_gateway_id: IPv6网关的ID。
        :param pulumi.Input[builtins.str] isp: IPv6公网带宽的线路类型。BGP：BGP（多线）。
        :param pulumi.Input[builtins.str] lock_reason: IPv6公网带宽被锁定的原因。该参数只有IPv6公网带宽处于FinancialLocked状态时才有返回值。Financial：因欠费被锁定。Security：因安全被锁定。
        :param pulumi.Input[builtins.str] network_type: IPv6地址的通信类型。Private：私网通信类型。Public：公网通信类型。
        :param pulumi.Input[builtins.str] overdue_time: IPv6公网带宽欠费关停的时间。
        :param pulumi.Input[builtins.str] project_name: IPv6公网带宽的项目。
        :param pulumi.Input[builtins.bool] service_managed: 是否为服务托管。
        :param pulumi.Input[builtins.str] status: IPv6公网带宽的状态。Creating：创建中。Available：可用。
        :param pulumi.Input[builtins.str] updated_time: IPv6公网带宽的最近操作时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _Ipv6AddressBandwidthState.__new__(_Ipv6AddressBandwidthState)

        __props__.__dict__["allocation_id"] = allocation_id
        __props__.__dict__["bandwidth"] = bandwidth
        __props__.__dict__["bandwidth_package_id"] = bandwidth_package_id
        __props__.__dict__["billing_type"] = billing_type
        __props__.__dict__["business_status"] = business_status
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["deleted_time"] = deleted_time
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["instance_type"] = instance_type
        __props__.__dict__["ipv6_address"] = ipv6_address
        __props__.__dict__["ipv6_gateway_id"] = ipv6_gateway_id
        __props__.__dict__["isp"] = isp
        __props__.__dict__["lock_reason"] = lock_reason
        __props__.__dict__["network_type"] = network_type
        __props__.__dict__["overdue_time"] = overdue_time
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["service_managed"] = service_managed
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_time"] = updated_time
        return Ipv6AddressBandwidth(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allocationId")
    def allocation_id(self) -> pulumi.Output[builtins.str]:
        """
        IPv6公网带宽的ID。
        """
        return pulumi.get(self, "allocation_id")

    @property
    @pulumi.getter
    def bandwidth(self) -> pulumi.Output[builtins.int]:
        """
        IPv6公网带宽的带宽上限。
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="bandwidthPackageId")
    def bandwidth_package_id(self) -> pulumi.Output[builtins.str]:
        """
        IPv6共享带宽包的ID。
        """
        return pulumi.get(self, "bandwidth_package_id")

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> pulumi.Output[builtins.int]:
        """
        IPv6公网带宽的计费类型。2：按量计费-按带宽上限计费。3：按量计费-按实际流量计费。
        """
        return pulumi.get(self, "billing_type")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> pulumi.Output[builtins.str]:
        """
        IPv6公网带宽是否被锁定。Normal：正常。FinancialLocked：被锁定。
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        IPv6公网带宽的开通时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> pulumi.Output[builtins.str]:
        """
        IPv6公网带宽的删除时间。
        """
        return pulumi.get(self, "deleted_time")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        IPv6公网带宽关联的实例ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Output[builtins.str]:
        """
        IPv6公网带宽关联的实例类型。EcsInstance：云服务器实例。ClbInstance：负载均衡。
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="ipv6Address")
    def ipv6_address(self) -> pulumi.Output[builtins.str]:
        """
        IPv6地址。
        """
        return pulumi.get(self, "ipv6_address")

    @property
    @pulumi.getter(name="ipv6GatewayId")
    def ipv6_gateway_id(self) -> pulumi.Output[builtins.str]:
        """
        IPv6网关的ID。
        """
        return pulumi.get(self, "ipv6_gateway_id")

    @property
    @pulumi.getter
    def isp(self) -> pulumi.Output[builtins.str]:
        """
        IPv6公网带宽的线路类型。BGP：BGP（多线）。
        """
        return pulumi.get(self, "isp")

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> pulumi.Output[builtins.str]:
        """
        IPv6公网带宽被锁定的原因。该参数只有IPv6公网带宽处于FinancialLocked状态时才有返回值。Financial：因欠费被锁定。Security：因安全被锁定。
        """
        return pulumi.get(self, "lock_reason")

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> pulumi.Output[builtins.str]:
        """
        IPv6地址的通信类型。Private：私网通信类型。Public：公网通信类型。
        """
        return pulumi.get(self, "network_type")

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> pulumi.Output[builtins.str]:
        """
        IPv6公网带宽欠费关停的时间。
        """
        return pulumi.get(self, "overdue_time")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        IPv6公网带宽的项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="serviceManaged")
    def service_managed(self) -> pulumi.Output[builtins.bool]:
        """
        是否为服务托管。
        """
        return pulumi.get(self, "service_managed")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        IPv6公网带宽的状态。Creating：创建中。Available：可用。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.Ipv6AddressBandwidthTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        IPv6公网带宽的最近操作时间。
        """
        return pulumi.get(self, "updated_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetAllowListResult',
    'AwaitableGetAllowListResult',
    'get_allow_list',
    'get_allow_list_output',
]

@pulumi.output_type
class GetAllowListResult:
    """
    A collection of values returned by getAllowList.
    """
    def __init__(__self__, allow_list_category=None, allow_list_desc=None, allow_list_id=None, allow_list_ip_num=None, allow_list_name=None, allow_list_type=None, allow_lists=None, associated_instance_num=None, associated_instances=None, id=None, ip_address=None, modify_mode=None, security_group_bind_infos=None, update_security_group=None, user_allow_list=None):
        if allow_list_category and not isinstance(allow_list_category, str):
            raise TypeError("Expected argument 'allow_list_category' to be a str")
        pulumi.set(__self__, "allow_list_category", allow_list_category)
        if allow_list_desc and not isinstance(allow_list_desc, str):
            raise TypeError("Expected argument 'allow_list_desc' to be a str")
        pulumi.set(__self__, "allow_list_desc", allow_list_desc)
        if allow_list_id and not isinstance(allow_list_id, str):
            raise TypeError("Expected argument 'allow_list_id' to be a str")
        pulumi.set(__self__, "allow_list_id", allow_list_id)
        if allow_list_ip_num and not isinstance(allow_list_ip_num, int):
            raise TypeError("Expected argument 'allow_list_ip_num' to be a int")
        pulumi.set(__self__, "allow_list_ip_num", allow_list_ip_num)
        if allow_list_name and not isinstance(allow_list_name, str):
            raise TypeError("Expected argument 'allow_list_name' to be a str")
        pulumi.set(__self__, "allow_list_name", allow_list_name)
        if allow_list_type and not isinstance(allow_list_type, str):
            raise TypeError("Expected argument 'allow_list_type' to be a str")
        pulumi.set(__self__, "allow_list_type", allow_list_type)
        if allow_lists and not isinstance(allow_lists, list):
            raise TypeError("Expected argument 'allow_lists' to be a list")
        pulumi.set(__self__, "allow_lists", allow_lists)
        if associated_instance_num and not isinstance(associated_instance_num, int):
            raise TypeError("Expected argument 'associated_instance_num' to be a int")
        pulumi.set(__self__, "associated_instance_num", associated_instance_num)
        if associated_instances and not isinstance(associated_instances, list):
            raise TypeError("Expected argument 'associated_instances' to be a list")
        pulumi.set(__self__, "associated_instances", associated_instances)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip_address and not isinstance(ip_address, str):
            raise TypeError("Expected argument 'ip_address' to be a str")
        pulumi.set(__self__, "ip_address", ip_address)
        if modify_mode and not isinstance(modify_mode, str):
            raise TypeError("Expected argument 'modify_mode' to be a str")
        pulumi.set(__self__, "modify_mode", modify_mode)
        if security_group_bind_infos and not isinstance(security_group_bind_infos, list):
            raise TypeError("Expected argument 'security_group_bind_infos' to be a list")
        pulumi.set(__self__, "security_group_bind_infos", security_group_bind_infos)
        if update_security_group and not isinstance(update_security_group, bool):
            raise TypeError("Expected argument 'update_security_group' to be a bool")
        pulumi.set(__self__, "update_security_group", update_security_group)
        if user_allow_list and not isinstance(user_allow_list, str):
            raise TypeError("Expected argument 'user_allow_list' to be a str")
        pulumi.set(__self__, "user_allow_list", user_allow_list)

    @property
    @pulumi.getter(name="allowListCategory")
    def allow_list_category(self) -> builtins.str:
        """
        白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时无默认值，不传入时则查询所有类别的白名单。
        """
        return pulumi.get(self, "allow_list_category")

    @property
    @pulumi.getter(name="allowListDesc")
    def allow_list_desc(self) -> builtins.str:
        """
        白名单的描述信息。长度在 200 字符以内。默认值为空字符串。
        """
        return pulumi.get(self, "allow_list_desc")

    @property
    @pulumi.getter(name="allowListId")
    def allow_list_id(self) -> builtins.str:
        """
        白名单 ID。
        """
        return pulumi.get(self, "allow_list_id")

    @property
    @pulumi.getter(name="allowListIpNum")
    def allow_list_ip_num(self) -> builtins.int:
        """
        白名单中 IP 地址或 IP 地址段的数量。
        """
        return pulumi.get(self, "allow_list_ip_num")

    @property
    @pulumi.getter(name="allowListName")
    def allow_list_name(self) -> builtins.str:
        """
        白名单名称的命名规则如下：在当前地域内，白名单名称唯一。以中文、字母或下划线（*）开头。只能包含中文、字母、数字、下划线（*）和中划线（-）。长度为 1~128 个字符。
        """
        return pulumi.get(self, "allow_list_name")

    @property
    @pulumi.getter(name="allowListType")
    def allow_list_type(self) -> builtins.str:
        """
        白名单采用的网络协议类型。取值为 IPv4（默认值）。
        """
        return pulumi.get(self, "allow_list_type")

    @property
    @pulumi.getter(name="allowLists")
    def allow_lists(self) -> Sequence[builtins.str]:
        """
        白名单中包含的 IP 地址。支持以下两种格式：IP 地址格式。例如：10.23.12.24。CIDR 的 IP 地址段格式。例如：10.23.12.0/24（无类别域间路由，24 表示了地址中前缀的长度，范围为 1~32）。说明每个白名单最多可添加 300 个 IP 或 IP 地址段，当 IP 较多时，建议合并为 IP 段填入，例如10.23.12.0/24。禁止将 0.0.0.0/0 之外的形如 x.x.x.x/0 结尾的 IP 地址加入白名单。该字段不能与 UserAllowList 字段同时使用。
        """
        return pulumi.get(self, "allow_lists")

    @property
    @pulumi.getter(name="associatedInstanceNum")
    def associated_instance_num(self) -> builtins.int:
        """
        该白名单绑定的实例数量。
        """
        return pulumi.get(self, "associated_instance_num")

    @property
    @pulumi.getter(name="associatedInstances")
    def associated_instances(self) -> Sequence['outputs.GetAllowListAssociatedInstanceResult']:
        """
        该白名单绑定的实例列表，包含实例 ID 和实例名称信息。
        """
        return pulumi.get(self, "associated_instances")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> builtins.str:
        """
        按 IP 地址查询白名单。支持传入多个 IP 地址，多个 IP 地址使用英文逗号（,）分隔。说明如果白名单包含了多个 IP 地址的任意子集，该白名单就会被返回。
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter(name="modifyMode")
    def modify_mode(self) -> builtins.str:
        """
        修改白名单的方式。取值：Cover：覆盖，即使用 AllowList 字段的值覆盖原白名单。默认值。Append：追加，即在原白名单中增加 AllowList 字段包含的 IP 地址。Delete：删除，即在原白名单中删除 AllowList 字段包含的 IP 地址。至少需要保留一个 IP 地址。注意如需修改的白名单绑定有安全组，或需要在修改白名单时为白名单绑定安全组，则 ModifyMode 只能取值为 Cover。
        """
        return pulumi.get(self, "modify_mode")

    @property
    @pulumi.getter(name="securityGroupBindInfos")
    def security_group_bind_infos(self) -> Sequence['outputs.GetAllowListSecurityGroupBindInfoResult']:
        """
        该白名单绑定的安全组列表。
        """
        return pulumi.get(self, "security_group_bind_infos")

    @property
    @pulumi.getter(name="updateSecurityGroup")
    def update_security_group(self) -> builtins.bool:
        """
        是否更新白名单所绑定的安全组。取值：true：更新。false：不更新。默认值。
        """
        return pulumi.get(self, "update_security_group")

    @property
    @pulumi.getter(name="userAllowList")
    def user_allow_list(self) -> builtins.str:
        """
        安全组之外的、需要加入白名单的 IP 地址。可输入 IP 地址或 CIDR 格式的 IP 地址段。说明该字段不能与 AllowList 字段同时使用。
        """
        return pulumi.get(self, "user_allow_list")


class AwaitableGetAllowListResult(GetAllowListResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAllowListResult(
            allow_list_category=self.allow_list_category,
            allow_list_desc=self.allow_list_desc,
            allow_list_id=self.allow_list_id,
            allow_list_ip_num=self.allow_list_ip_num,
            allow_list_name=self.allow_list_name,
            allow_list_type=self.allow_list_type,
            allow_lists=self.allow_lists,
            associated_instance_num=self.associated_instance_num,
            associated_instances=self.associated_instances,
            id=self.id,
            ip_address=self.ip_address,
            modify_mode=self.modify_mode,
            security_group_bind_infos=self.security_group_bind_infos,
            update_security_group=self.update_security_group,
            user_allow_list=self.user_allow_list)


def get_allow_list(id: Optional[builtins.str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAllowListResult:
    """
    Data Source schema for Byteplus::RDSPostgreSQL::AllowList


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:rdspostgresql/getAllowList:getAllowList', __args__, opts=opts, typ=GetAllowListResult).value

    return AwaitableGetAllowListResult(
        allow_list_category=pulumi.get(__ret__, 'allow_list_category'),
        allow_list_desc=pulumi.get(__ret__, 'allow_list_desc'),
        allow_list_id=pulumi.get(__ret__, 'allow_list_id'),
        allow_list_ip_num=pulumi.get(__ret__, 'allow_list_ip_num'),
        allow_list_name=pulumi.get(__ret__, 'allow_list_name'),
        allow_list_type=pulumi.get(__ret__, 'allow_list_type'),
        allow_lists=pulumi.get(__ret__, 'allow_lists'),
        associated_instance_num=pulumi.get(__ret__, 'associated_instance_num'),
        associated_instances=pulumi.get(__ret__, 'associated_instances'),
        id=pulumi.get(__ret__, 'id'),
        ip_address=pulumi.get(__ret__, 'ip_address'),
        modify_mode=pulumi.get(__ret__, 'modify_mode'),
        security_group_bind_infos=pulumi.get(__ret__, 'security_group_bind_infos'),
        update_security_group=pulumi.get(__ret__, 'update_security_group'),
        user_allow_list=pulumi.get(__ret__, 'user_allow_list'))
def get_allow_list_output(id: Optional[pulumi.Input[builtins.str]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAllowListResult]:
    """
    Data Source schema for Byteplus::RDSPostgreSQL::AllowList


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:rdspostgresql/getAllowList:getAllowList', __args__, opts=opts, typ=GetAllowListResult)
    return __ret__.apply(lambda __response__: GetAllowListResult(
        allow_list_category=pulumi.get(__response__, 'allow_list_category'),
        allow_list_desc=pulumi.get(__response__, 'allow_list_desc'),
        allow_list_id=pulumi.get(__response__, 'allow_list_id'),
        allow_list_ip_num=pulumi.get(__response__, 'allow_list_ip_num'),
        allow_list_name=pulumi.get(__response__, 'allow_list_name'),
        allow_list_type=pulumi.get(__response__, 'allow_list_type'),
        allow_lists=pulumi.get(__response__, 'allow_lists'),
        associated_instance_num=pulumi.get(__response__, 'associated_instance_num'),
        associated_instances=pulumi.get(__response__, 'associated_instances'),
        id=pulumi.get(__response__, 'id'),
        ip_address=pulumi.get(__response__, 'ip_address'),
        modify_mode=pulumi.get(__response__, 'modify_mode'),
        security_group_bind_infos=pulumi.get(__response__, 'security_group_bind_infos'),
        update_security_group=pulumi.get(__response__, 'update_security_group'),
        user_allow_list=pulumi.get(__response__, 'user_allow_list')))
